pm4py.algo package
==================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.analysis
   pm4py.algo.clustering
   pm4py.algo.comparison
   pm4py.algo.conformance
   pm4py.algo.decision_mining
   pm4py.algo.discovery
   pm4py.algo.enhancement
   pm4py.algo.evaluation
   pm4py.algo.filtering
   pm4py.algo.organizational_mining
   pm4py.algo.reduction
   pm4py.algo.simulation
   pm4py.algo.transformation

Module contents
---------------

.. automodule:: pm4py.algo
   :members:
   :undoc-members:
   :show-inheritance:
